##  Aggregation and Linkage of Software Records
You can import software records from ServiceNow as aggregated software fact sheets and automatically link these consolidated fact sheets to the reference catalog that provides lifecycle data for obsolescence risk management. By using the aggregation and linkage feature, you can streamline the import process and enhance data quality. To learn more about this feature and how to use it, see [Aggregation and Linkage of Software Records](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records?locale=en-US&state=PRODUCTION&version=CLOUD "The aggregation and linkage feature allows you to import multiple software records from ServiceNow in an aggregated way while automatically linking consolidated fact sheets to the reference catalog.").
